grabbag
=======

A number of useful helpers that don't seem to exist elsewhere.

Notables: 
* cached_property, 
* better error/exception wrapping + helpers, 
* better log wrapping + helpers
* process helpers
* easy file locks

TODO: documents somewhere somehow 

